mirror of
https://github.com/LostRuins/koboldcpp.git
synced 2026-09-18 16:55:14 +02:00
tentative fix for allReduce compile error from https://github.com/ggml-org/llama.cpp/pull/22299
This commit is contained in:
@@ -210,7 +210,9 @@ static __global__ void ggml_cuda_ar_add_kernel(
|
||||
const int nt = gridDim.x * blockDim.x;
|
||||
for (int i = tid; i < count; i += nt) {
|
||||
const T_src d_low = ggml_cuda_cast<T_src>(dst[i]);
|
||||
dst[i] = ggml_cuda_cast<T_dst>(d_low) + ggml_cuda_cast<T_dst>(src[i]);
|
||||
const float a = (float) ggml_cuda_cast<float>(d_low);
|
||||
const float b = (float) ggml_cuda_cast<float>(src[i]);
|
||||
dst[i] = ggml_cuda_cast<T_dst>(a + b);
|
||||
}
|
||||
}
|
||||
|
||||
|
||||
Reference in New Issue
Block a user